summaryrefslogtreecommitdiff
path: root/sw/inc/txttxmrk.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/inc/txttxmrk.hxx')
-rw-r--r--sw/inc/txttxmrk.hxx26
1 files changed, 13 insertions, 13 deletions
diff --git a/sw/inc/txttxmrk.hxx b/sw/inc/txttxmrk.hxx
index 6436b859f342..f935254fc682 100644
--- a/sw/inc/txttxmrk.hxx
+++ b/sw/inc/txttxmrk.hxx
@@ -21,34 +21,34 @@
#include <txatbase.hxx>
-class SwTxtNode;
+class SwTextNode;
class SwDoc;
// Attribute for indices/tables of contents.
-class SwTxtTOXMark : public SwTxtAttrEnd
+class SwTextTOXMark : public SwTextAttrEnd
{
- SwTxtNode * m_pTxtNode;
+ SwTextNode * m_pTextNode;
sal_Int32 * m_pEnd; // 0 if SwTOXMark without AlternativeText
public:
- SwTxtTOXMark( SwTOXMark& rAttr,
+ SwTextTOXMark( SwTOXMark& rAttr,
sal_Int32 const nStart, sal_Int32 const*const pEnd = 0);
- virtual ~SwTxtTOXMark();
+ virtual ~SwTextTOXMark();
- virtual sal_Int32 *GetEnd() SAL_OVERRIDE; // SwTxtAttr
+ virtual sal_Int32 *GetEnd() SAL_OVERRIDE; // SwTextAttr
void CopyTOXMark( SwDoc* pDestDoc );
- // get and set TxtNode pointer
- inline const SwTxtNode* GetpTxtNd() const { return m_pTxtNode; }
- inline const SwTxtNode& GetTxtNode() const;
- void ChgTxtNode( SwTxtNode* pNew ) { m_pTxtNode = pNew; }
+ // get and set TextNode pointer
+ inline const SwTextNode* GetpTextNd() const { return m_pTextNode; }
+ inline const SwTextNode& GetTextNode() const;
+ void ChgTextNode( SwTextNode* pNew ) { m_pTextNode = pNew; }
};
-inline const SwTxtNode& SwTxtTOXMark::GetTxtNode() const
+inline const SwTextNode& SwTextTOXMark::GetTextNode() const
{
- assert( m_pTxtNode );
- return *m_pTxtNode;
+ assert( m_pTextNode );
+ return *m_pTextNode;
}
#endif